@@ -1,6 +1,6 @@
 import json
 from collections.abc import Iterable
-from typing import Union
+from typing import Any, Union
 
 
 def valfilter(cond, dct):
@@ -47,7 +47,7 @@ def strip_patch_from_version(version: str) -> str:
     return ".".join(version.split(".")[:2])
 
 
-def is_string_truthy(bool_like):
+def is_string_truthy(bool_like: Any) -> bool:
     """
     This function tries to solve the annoying problem of checking whether a given
     string is thruthy or not. It also accepts booleans and None.
